==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>İş</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Həyat</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Digər</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Bağlayın</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Başlamadan bir gün əvvəl</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Mənə sabah xatırlat</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Mənə sonra xatırlat</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 dəq sonra</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 saat sonra</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 saat sonra</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Sabah</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Xatırlatma cədvəli</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 ilə %2 arası</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bu gün</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Başlamadan bir gün əvvəl</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Bağlayın</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Sabah mənə xatırlat</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Sonra mənə xatırlat</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Xatırlatma cədvəli</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 ilə %2 arası</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Bu gün</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Sabah</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>İş</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Həyat</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Digər</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Bağlayın</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Başlamadan bir gün əvvəl</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Mənə sabah xatırlat</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Mənə sonra xatırlat</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 dəq sonra</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 saat sonra</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 saat sonra</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Sabah</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Xatırlatma cədvəli</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 ilə %2 arası</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bu gün</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
